using System;
using System.Collections.Generic;
using System.IO;
using System.Reflection;
using System.Text;

namespace Crysanthem
{
    public class GameFieldList
    {
        public GameField this[int idx]
        {
            get { return fields[idx]; }
        }

        public int Count
        {
            get { return fields.Count; }
        }

        private List<GameField> fields = new List<GameField>();
        private List<float> times = new List<float>();

        public GameFieldList(Resources res)
        {
            Assembly asm = Assembly.GetCallingAssembly();
            String[] resources = asm.GetManifestResourceNames();

            foreach (String res_name in resources)
            {
#if XBOX
                if (!res_name.StartsWith("Crysanthem360.Levels."))
                    continue;
#else
                if (!res_name.StartsWith("Crysanthem.Levels."))
                    continue;
#endif

                GameField field = LoadField(res, res_name);
                if (field != null)
                {
                    fields.Add(field);
                    times.Add(-1.0f);
                }
            }

            // Sort the fields
            fields.Sort(delegate(GameField f1, GameField f2) { return String.Compare(f1.sort_name, f2.sort_name, true); });

            // Set the field indices
            for (int i = 0; i < fields.Count; ++i)
                fields[i].level_index = i;
        }

        public float GetTime(int idx)
        {
            return times[idx];
        }

        public void SetTime(int idx, float time)
        {
            if (times[idx] >= 0.0f && time > times[idx])
                return;
            times[idx] = time;
        }

        private GameField LoadField(Resources res, String res_name)
        {
            Console.WriteLine("Loading level from resources: '{0}'", res_name);

            try
            {
                Assembly asm = Assembly.GetCallingAssembly();

                using (TextReader stm = new StreamReader(asm.GetManifestResourceStream(res_name)))
                {
                    GameField fld = new GameField(res, stm);
                    fld.sort_name = res_name;

                    return fld;
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("Error loading level:");
                Console.WriteLine(e);
            }
            return null;
        }
    }
}
