using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Crysanthem;

namespace Crysanthem.Screen
{
    public abstract class Screen : DrawableGameComponent
    {
        protected Resources res;

        protected abstract GameField CurrentField { get; }

        protected abstract String[] InfoLines { get; }

        private int m_cur_line;
        private float m_pause;

        public Screen(Resources _res)
            : base(_res.game)
        {
            res = _res;
        }

        public override void Update(GameTime gameTime)
        {
            base.Update(gameTime);

            m_pause += (float)gameTime.ElapsedRealTime.TotalSeconds;
            if (m_pause > 3.5f)
            {
                m_pause = 0.0f;
                m_cur_line = (m_cur_line + 1) % InfoLines.Length;
            }
        }

        public override void Draw(GameTime gameTime)
        {
            GameField f = CurrentField;

            // Sanity check
            if (m_cur_line >= InfoLines.Length)
            {
                m_cur_line = 0;
                m_pause = 0;
            }

            // Draw the help texts
            res.sprite_batch.Begin();
            res.sprite_batch.DrawString(
                res.font,
                "Level " + (f.level_index+1) + ": " + f.name + "   -- " + InfoLines[m_cur_line],
                new Vector2(4.0f, 0.0f),
                Color.Black);
            res.sprite_batch.End();
        }
    }
}
